# fasthep-flow

[![Actions Status][actions-badge]][actions-link]
[![Documentation Status][rtd-badge]][rtd-link]

[![PyPI version][pypi-version]][pypi-link]
[![Conda-Forge][conda-badge]][conda-link]
[![PyPI platforms][pypi-platforms]][pypi-link]

[![GitHub Discussion][github-discussions-badge]][github-discussions-link]

<!-- SPHINX-START -->

<!-- prettier-ignore-start -->
[actions-badge]:            https://github.com/FAST-HEP/fasthep-flow/workflows/CI/badge.svg
[actions-link]:             https://github.com/FAST-HEP/fasthep-flow/actions
[conda-badge]:              https://img.shields.io/conda/vn/conda-forge/fasthep-flow
[conda-link]:               https://github.com/conda-forge/fasthep-flow-feedstock
[github-discussions-badge]: https://img.shields.io/static/v1?label=Discussions&message=Ask&color=blue&logo=github
[github-discussions-link]:  https://github.com/FAST-HEP/fasthep-flow/discussions
[pypi-link]:                https://pypi.org/project/fasthep-flow/
[pypi-platforms]:           https://img.shields.io/pypi/pyversions/fasthep-flow
[pypi-version]:             https://img.shields.io/pypi/v/fasthep-flow
[rtd-badge]:                https://readthedocs.org/projects/fasthep-flow/badge/?version=latest
[rtd-link]:                 https://fasthep-flow.readthedocs.io/en/latest/?badge=latest

<!-- prettier-ignore-end -->

## Introduction

## Documentation

## Installation

## Examples

## Contributing

## License

## Acknowledgements

Special thanks to the gracious help of FAST-HEP contributors:

<!-- readme: m-glowacki,seriksen,collaborators,contributors -start -->
<table>
<tr>
    <td align="center">
        <a href="https://github.com/m-glowacki">
            <img src="https://avatars.githubusercontent.com/u/69155366?v=4" width="100;" alt="m-glowacki"/>
            <br />
            <sub><b>Maciek Glowacki</b></sub>
        </a>
    </td>
    <td align="center">
        <a href="https://github.com/seriksen">
            <img src="https://avatars.githubusercontent.com/u/5619270?v=4" width="100;" alt="seriksen"/>
            <br />
            <sub><b>Null</b></sub>
        </a>
    </td>
    <td align="center">
        <a href="https://github.com/kreczko">
            <img src="https://avatars.githubusercontent.com/u/1213276?v=4" width="100;" alt="kreczko"/>
            <br />
            <sub><b>Luke Kreczko</b></sub>
        </a>
    </td></tr>
</table>
<!-- readme: m-glowacki,seriksen,collaborators,contributors -end -->
